@@ -39,3 +39,15 @@ def test_command_line_interface():
 
 def test_add():
     assert math_base.add(3, 4) == 7
+
+
+def test_factorial_1():
+    assert math_base.factorial(5) == 120
+
+
+def test_factorial_2():
+    assert math_base.factorial(2) == 2
+
+
+def test_combination():
+    assert math_base.combination(5, 2) == 60
